/****************************************************************************
**
** Copyright (C) 2005-2006 Trolltech AS. All rights reserved.
**
** This file is part of the example classes of the Qt Toolkit.
**
** This file may be used under the terms of the GNU General Public
** License version 2.0 as published by the Free Software Foundation
** and appearing in the file LICENSE.GPL included in the packaging of
** this file.  Please review the following information to ensure GNU
** General Public Licensing requirements will be met:
** http://www.trolltech.com/products/qt/opensource.html
**
** If you are unsure which license is appropriate for your use, please
** review the following information:
** http://www.trolltech.com/products/qt/licensing.html or contact the
** sales department at sales@trolltech.com.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
****************************************************************************/

#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>
#include <QSystemTrayIcon>

class BrowserTree;
class QMenu;
class QStatusBar;
class QAction;
class QSystemTrayIcon;

class MainWindow : public QMainWindow
{
    Q_PROPERTY(QStringList runningApplications READ runningApplications)
    Q_OBJECT

public:
    MainWindow(QWidget* parent_w);
    ~MainWindow();
    
    QMenu *viewMenu;
    QMenu *goMenu;
    QAction *openAct;
    QAction *saveAsAct;
    QAction *exitAct;
    QAction *aboutAct;
    QAction *aboutQtAct;
    QAction *helpIconAct;
    QAction* viewFindAct;
    QAction* viewHtml;
    QAction* viewExecHeader;
    QAction* viewStateHeader;
    QAction* viewDescriptionHeader;
    QAction* findAction;
    QAction* searchSystrayAction;
    QAction* restartAction;
    QAction *unlockHeadersAction;
    QAction *viewDBusServiceAction;
    QSystemTrayIcon *TrayIcon() { return trayIcon; }

    QStringList runningApplications() const;

   protected:
    void closeEvent(QCloseEvent* e);

private slots:
    void open();
    void saveAs();
    void about();
    void view_html();
    void killmenu();
    void iconActivated(QSystemTrayIcon::ActivationReason reason);
    void ReloadBrowser();
    void find_from_systray();
    void raiseFromDBusMessage();

private:
    void createMenus();

    BrowserTree *browserTree;

    QMenu *fileMenu;
    QMenu *helpMenu;
    QMenu *toolsMenu;
    
    /* System tray icon objects */
    QAction *minimizeAction;
    QAction *maximizeAction;
    QAction *restoreAction;
    QAction *quitAction;
    QSystemTrayIcon *trayIcon;
    QMenu *trayIconMenu;
    void CreateSysTrayIconActions();
    void CreateTrayIcon();
    bool never_told_about_systray;
    
};

#endif
